```
Usage: vcd right list [OPTIONS]

Options:
  -o, --org [org-name]  name of the org
  --all                 list all rights available in the System
  -h, --help            Show this message and exit.

```
